==> haskell-lifted-async-0.9.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.1.1
id: lifted-async-0.9.1.1-YhJ9WH1OyT5480945Dhv4
key: lifted-async-0.9.1.1-YhJ9WH1OyT5480945Dhv4
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: c885102ef8fb91b31fb1fcef0c9909ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/lifted-async-0.9.1.1
hs-libraries: HSlifted-async-0.9.1.1-YhJ9WH1OyT5480945Dhv4
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    constraints-0.9-LCN0LfmsvhJCB3djHt91pr
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.9.1.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.1.1
id: lifted-async-0.9.1.1-1mz36Kkb1TO6yyUhnzbGf6
key: lifted-async-0.9.1.1-1mz36Kkb1TO6yyUhnzbGf6
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: 05c355fdb4fe71348c919ccd67ded806
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/lifted-async-0.9.1.1
hs-libraries: HSlifted-async-0.9.1.1-1mz36Kkb1TO6yyUhnzbGf6
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    constraints-0.9.1-DKR0IYO2G7HLCiIzI9u5w9
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
